aIc.dominant: aIc.dominant calculates the subcompositional dominance of a sample in
a dataset for a given correction. This compares the distances of samples
of the full dataset and a subset of the dataset.
This is expected to be true if the transform is behaving rationally in
compositional datasets.
Description
aIc.dominant calculates the subcompositional dominance of a sample in
a dataset for a given correction. This compares the distances of samples
of the full dataset and a subset of the dataset.
This is expected to be true if the transform is behaving rationally in
compositional datasets.
Returns a list with the overlap between distances in the full and
subcompositon in ol (expect 0), a yes/no binary decision in
is.dominant and the table of distances for the whole and subcomposition
in dist.all and dist.sub, a plot showing a histogram of the resulting
overlap in distances in plot, and the plot and axis
labels in main
xlab and ylab
Arguments
data
can be any dataframe or matrix with samples by column
norm.method
can be prop, clr, RLE, TMM, TMMwsp
zero.remove
is a value. Filter data to remove features that are 0
across at least that proportion of samples: default 0.95
zero.method
can be any of NULL, prior, GBM or CZM. NULL will not
impute or change 0 values, GBM (preferred) and CZM are from the
zCompositions R package, and prior will simply add 0.5 to all counts.
log
is a logical. log transform the RLE or TMM outputs, default=FALSE
distance
can be euclidian, bray, or jaccard. euclidian on log-ratio
transformed data is the same as the Aitchison distance. default=euclidian
group
is a vector containing group information. Required for clr, RLE,
TMM, lvha, and iqlr based normalizations.