Learn R Programming

aIc (version 1.0)

metaTscome: meta-transcriptome data

Description

A count table of a mixed population or metatranscriptome experiment. Two groups, H and BV are represented with 7 and 10 samples per group respectively. samples are by column and functions are by row.

Usage

data(metaTscome)

Arguments

Format

A data frame with 17 columns and 3647 rows