aIc.coherent: Calculate the subcompositional coherence of samples in
a dataset for a given correction.
Description
`aIc.coherent` compares the correlation coefficients
of features in common of the full dataset and a subset of the dataset.
This is expected to be false for all compositional datasets and transforms.
Returns a list with the correlation in cor, a yes/no binary
decision in is.coherent, the x and y values for a scatterplot
of the correlations in the full and subcompositions, and the plot and axis
labels in main
xlab and ylab.
Arguments
data
can be any dataframe or matrix with samples by column
norm.method
can be prop, clr, RLE, TMM, TMMwsp, lvha, iqlr
zero.remove
is a value. Filter data to remove features that are 0
across at least that proportion of samples: default 0.95
zero.method
can be any of NULL, prior, GBM or CZM. NULL will not
impute or change 0 values, GBM and CZM are from the
zCompositions R package, and prior will simply add 0.5 to all counts.
log
is a logical. log transform the prop, RLE or TMM outputs, default=FALSE
group
is a vector containing group information. Required for clr, RLE,
cor.test
is either the pearson or spearman method (default)